import { GunEvent } from '../ControlFlow/GunEvent';
import { GunProcessQueue } from '../ControlFlow/GunProcessQueue';
import { GunGraph } from '../Graph/GunGraph';
export declare abstract class GunGraphConnector {
    name: string;
    isConnected: boolean;
    events: {
        graphData: GunEvent<GunGraphData, string | undefined, string | undefined>;
        receiveMessage: GunEvent<GunMsg>;
        connection: GunEvent<boolean>;
    };
    protected inputQueue: GunProcessQueue<GunMsg>;
    protected outputQueue: GunProcessQueue<GunMsg>;
    constructor(name?: string);
    connectToGraph(graph: GunGraph): this;
    off(msgId: string): this;
    sendPutsFromGraph(graph: GunGraph): void;
    sendRequestsFromGraph(graph: GunGraph): void;
    waitForConnection(): Promise<unknown>;
    /**
     * Send graph data for one or more nodes
     *
     * @returns A function to be called to clean up callback listeners
     */
    put({ graph, msgId, replyTo, cb }: ChainGunPut): () => void;
    /**
     * Request data for a given soul
     *
     * @returns A function to be called to clean up callback listeners
     */
    get({ soul, cb, msgId, key }: ChainGunGet): () => void;
    /**
     * Queues outgoing messages for sending
     *
     * @param msgs The Gun wire protocol messages to enqueue
     */
    send(msgs: GunMsg[]): void;
    /**
     * Queue incoming messages for processing
     *
     * @param msgs
     */
    ingest(msgs: GunMsg[]): void;
    private __onConnectedChange;
}
